@@ -31,9 +31,9 @@ class DjangoProject(Project):
         requirements_txt = self.project_path / 'requirements.txt'
         if requirements_txt.exists():
             return f'-r {requirements_txt.resolve()}'
-        return 'django<2'  # FIXME: this is a hack for djangogirls while they update to 2.x
-
-
+        return 'django'
+    
+    
     def run_startproject(self, nuke):
         print(snakesay('Starting Django project'))
         if nuke and self.project_path.exists():
