@@ -1,7 +1,11 @@
 from pathlib import Path
+import uuid
+
 from pythonanywhere.api import Webapp
 from pythonanywhere.exceptions import SanityException
 from pythonanywhere.virtualenvs import Virtualenv
+from pythonanywhere.launch_bash_in_virtualenv import launch_bash_in_virtualenv
+from pythonanywhere.snakesay import snakesay
 
 
 class Project:
@@ -31,3 +35,9 @@ class Project:
     def add_static_file_mappings(self):
         self.webapp.add_default_static_files_mappings(self.project_path)
 
+
+    def start_bash(self):
+        print(snakesay(f'Starting Bash shell with activated virtualenv in project directory.  Press Ctrl+D to exit.'))
+        unique_id = str(uuid.uuid4())
+        launch_bash_in_virtualenv(self.virtualenv.path, unique_id, self.project_path)
+
